@@ -8,6 +8,7 @@ import os
 import random
 import matplotlib.pyplot as plt
 import shutil
+import time
 
 from tensorflow.keras.layers import Conv2D, BatchNormalization, Activation, MaxPool2D, Dropout, Flatten, Dense
 
@@ -277,6 +278,7 @@ def process():
     model.summary()
 
 def predictPicture(modelpath,imagepath):
+    s = time.time()
     imagepath = r"{}".format(imagepath)
     model = Baseline()
     checkpoint_path = os.path.join(modelpath,"save.ckpt")
@@ -296,8 +298,9 @@ def predictPicture(modelpath,imagepath):
     imagename = os.path.basename(imagepath)
     maybe = result_index[0]
     percent = 100.0*result[0][maybe]
+    e = time.time
     
-    result = "name:{},maybe:{},percent:{}%".format(imagename,maybe,round(percent,2))
+    result = "name:{},maybe:{},percent:{}%,spend:{}s".format(imagename,maybe,round(percent,2),round(e-s,2))
     return result
 
 
